@@ -159,9 +159,13 @@ final class JarClassPath implements ClassPath {
         URL jarURL = find(classname);
         if (null != jarURL)
             try {
-                java.net.URLConnection con = jarURL.openConnection();
-                con.setUseCaches(false);
-                return con.getInputStream();
+                if (ClassPool.cacheOpenedJarFile)
+                    return jarURL.openConnection().getInputStream();
+                else {
+                    java.net.URLConnection con = jarURL.openConnection();
+                    con.setUseCaches(false);
+                    return con.getInputStream();
+                }
             }
             catch (IOException e) {
                 throw new NotFoundException("broken jar file?: "
