@@ -22,6 +22,9 @@ import javassist.compiler.CompileError;
  * Instanceof expression.
  */
 public class InstanceOfExpr extends CastExpr {
+    /** default serialVersionUID */
+    private static final long serialVersionUID = 1L;
+
     public InstanceOfExpr(ASTList className, int dim, ASTree expr) {
         super(className, dim, expr);
     }
@@ -30,10 +33,12 @@ public class InstanceOfExpr extends CastExpr {
         super(type, dim, expr);
     }
 
+    @Override
     public String getTag() {
         return "instanceof:" + castType + ":" + arrayDim;
     }
 
+    @Override
     public void accept(Visitor v) throws CompileError {
         v.atInstanceOfExpr(this);
     }
