@@ -340,7 +340,7 @@ public class JvstTest3 extends JvstTestRoot {
         System.out.println("Num Annotation : " +ans.length);
 
         // c.debugWriteFile();
-        Class newclass = c.toClass();
+        Class newclass = c.toClass(DefineClassCapability.class);
         java.lang.annotation.Annotation[] anns = newclass.getAnnotations();
         System.out.println("Num NewClass Annotation : " +anns.length);
         assertEquals(ans.length, anns.length);
@@ -586,6 +586,20 @@ public class JvstTest3 extends JvstTestRoot {
         assertEquals(524, invoke(obj, "test"));
     }
 
+    public void testMethodRedirectToStatic() throws Exception {
+        CtClass targetClass = sloader.get("test3.MethodRedirectToStatic");
+        CtClass staticClass = sloader.get("test3.MethodRedirectToStatic2");
+        CtMethod targetMethod = targetClass.getDeclaredMethod("add");
+        CtMethod staticMethod = staticClass.getDeclaredMethod("add2");
+        CodeConverter conv = new CodeConverter();
+
+        conv.redirectMethodCallToStatic(targetMethod, staticMethod);
+        targetClass.instrument(conv);
+        targetClass.writeFile();
+        Object obj = make(targetClass.getName());
+        assertEquals(30, invoke(obj, "test"));
+    }
+
     public void testClassMap() throws Exception {
         ClassMap map = new ClassMap();
         map.put("aa", "AA");
@@ -737,7 +751,7 @@ public class JvstTest3 extends JvstTestRoot {
         CtMethod m2 = cc2.getDeclaredMethod("getX");
         copyAnnotations(m1, m2);
         cc2.getClassFile();
-        Class clazz = cc2.toClass();
+        Class clazz = cc2.toClass(DefineClassCapability.class);
         java.lang.reflect.Method m = clazz.getDeclaredMethod("getX", new Class[0]);
         assertEquals(1, m.getAnnotations().length);
         test3.VisibleAnno a = m.getAnnotation(test3.VisibleAnno.class);
@@ -790,7 +804,7 @@ public class JvstTest3 extends JvstTestRoot {
         cc.addField(fobj, CtField.Initializer.constant("bar"));
 
         cc.writeFile();
-        Class clazz = cc.toClass();
+        Class clazz = cc.toClass(DefineClassCapability.class);
         assertEquals(2L, clazz.getField("j").getLong(null));
         assertEquals(3, clazz.getField("i").getInt(null));
         assertEquals(4, clazz.getField("s").getShort(null));
@@ -1108,7 +1122,7 @@ public class JvstTest3 extends JvstTestRoot {
         sb.append("}"); 
         ctc.addMethod(CtNewMethod.make(sb.toString(), ctc));
         ctc.debugWriteFile();
-        ctc.toClass().getConstructor().newInstance();
+        ctc.toClass(DefineClassCapability.class).getConstructor().newInstance();
     }
 
     // JIRA-83
